@@ -28,10 +28,10 @@ class CustomFormatter (logging.Formatter):
     def format (self, record):
         """ Add ebook no. to string format params. """
         try:
-            ebook = int (ebook)
+            myebook = int (ebook)
         except ValueError:
-            ebook = 0
-        record.ebook = ebook
+            myebook = 0
+        record.ebook = myebook
         return logging.Formatter.format (self, record)
 
 
